@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.7.6"
+#define PYO_VERSION "0.7.9"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -108,7 +108,6 @@
 #define MYATAN2 atan2f
 #define MYEXP expf
 #define MYROUND roundf
-#define MYTANH tanhf
 
 #else
 #define LIB_BASE_NAME "_pyo64"
@@ -192,7 +191,6 @@
 #define MYATAN2 atan2
 #define MYEXP exp
 #define MYROUND round
-#define MYTANH tanh
 
 #endif
 #endif
@@ -201,6 +199,8 @@
 #include "externalmodule.h"
 #endif
 
+extern PyTypeObject MidiListenerType;
+extern PyTypeObject OscListenerType;
 extern PyTypeObject SineType;
 extern PyTypeObject SineLoopType;
 extern PyTypeObject FmType;
@@ -486,14 +486,18 @@ extern PyTypeObject MainParticleType;
 extern PyTypeObject ParticleType;
 extern PyTypeObject AtanTableType;
 extern PyTypeObject RawMidiType;
+extern PyTypeObject ResampleType;
+extern PyTypeObject ExprType;
 
 /* Constants */
 #define E M_E
 #define PI M_PI
 #define TWOPI (2 * M_PI)
 
+#define PYO_RAND_MAX 4294967295
+
 /* random uniform (0.0 -> 1.0) */
-#define RANDOM_UNIFORM rand()/((MYFLT)(RAND_MAX)+1)
+#define RANDOM_UNIFORM (pyorand()/((MYFLT)(PYO_RAND_MAX)+1))
 
 /* random objects identifier */
 #define BEATER_ID 0
@@ -585,8 +589,7 @@ extern PyTypeObject RawMidiType;
 
 #define pyo_CLEAR \
     if (self->server != NULL) { \
-        Py_INCREF(self->server); \
-        Py_CLEAR(self->server); \
+        self->server = NULL; \
     } \
     if (self->stream != NULL) \
         Py_CLEAR(self->stream); \
@@ -597,16 +600,14 @@ extern PyTypeObject RawMidiType;
 
 #define pyo_table_CLEAR \
     if (self->server != NULL) { \
-        Py_INCREF(self->server); \
-        Py_CLEAR(self->server); \
+        self->server = NULL; \
     } \
     if (self->tablestream != NULL) \
         Py_CLEAR(self->tablestream); \
 
 #define pyo_matrix_CLEAR \
     if (self->server != NULL) { \
-        Py_INCREF(self->server); \
-        Py_CLEAR(self->server); \
+        self->server = NULL; \
     } \
     if (self->matrixstream != NULL) \
         Py_CLEAR(self->matrixstream); \
@@ -616,6 +617,12 @@ extern PyTypeObject RawMidiType;
         Server_removeStream((Server *)self->server, Stream_getStreamId(self->stream)); \
     free(self->data); \
 
+#define ASSERT_ARG_NOT_NULL \
+	if (arg == NULL) { \
+		Py_INCREF(Py_None); \
+		return Py_None; \
+	}
+
 /* INIT INPUT STREAM */
 #define INIT_INPUT_STREAM \
     if ( PyObject_HasAttrString((PyObject *)inputtmp, "server") == 0 ) { \
@@ -681,7 +688,7 @@ extern PyTypeObject RawMidiType;
     TableStream_setSize(self->tablestream, self->size+1); \
  \
     for (i=0; i<(self->size); i++) { \
-        self->data[i] = PyFloat_AS_DOUBLE(PyNumber_Float(PyList_GET_ITEM(arg, i))); \
+        self->data[i] = PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
     } \
     self->data[self->size] = self->data[0]; \
     TableStream_setData(self->tablestream, self->data); \
@@ -709,7 +716,7 @@ extern PyTypeObject RawMidiType;
     for(i=0; i<self->height; i++) { \
         innerlist = PyList_GetItem(arg, i); \
         for (j=0; j<self->width; j++) { \
-            self->data[i][j] = PyFloat_AS_DOUBLE(PyNumber_Float(PyList_GET_ITEM(innerlist, j))); \
+            self->data[i][j] = PyFloat_AsDouble(PyList_GET_ITEM(innerlist, j)); \
         } \
     } \
  \
@@ -733,7 +740,7 @@ extern PyTypeObject RawMidiType;
     MYFLT *list = NULL; \
     PyObject *table = NULL; \
     if (PyNumber_Check(arg)) { \
-        x = PyFloat_AsDouble(PyNumber_Float(arg)); \
+        x = PyFloat_AsDouble(arg); \
         for (i=0; i<self->size; i++) { \
             self->data[i] += x; \
         } \
@@ -754,7 +761,7 @@ extern PyTypeObject RawMidiType;
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
-            self->data[i] += PyFloat_AS_DOUBLE(PyNumber_Float(PyList_GET_ITEM(arg, i))); \
+            self->data[i] += PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
         } \
     } \
  \
@@ -769,7 +776,7 @@ extern PyTypeObject RawMidiType;
     MYFLT *list = NULL; \
     PyObject *table = NULL; \
     if (PyNumber_Check(arg)) { \
-        x = PyFloat_AsDouble(PyNumber_Float(arg)); \
+        x = PyFloat_AsDouble(arg); \
         for (i=0; i<self->size; i++) { \
             self->data[i] -= x; \
         } \
@@ -790,7 +797,7 @@ extern PyTypeObject RawMidiType;
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
-            self->data[i] -= PyFloat_AS_DOUBLE(PyNumber_Float(PyList_GET_ITEM(arg, i))); \
+            self->data[i] -= PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
         } \
     } \
  \
@@ -805,7 +812,7 @@ extern PyTypeObject RawMidiType;
     MYFLT *list = NULL; \
     PyObject *table = NULL; \
     if (PyNumber_Check(arg)) { \
-        x = PyFloat_AsDouble(PyNumber_Float(arg)); \
+        x = PyFloat_AsDouble(arg); \
         for (i=0; i<self->size; i++) { \
             self->data[i] *= x; \
         } \
@@ -826,7 +833,7 @@ extern PyTypeObject RawMidiType;
         if (self->size < tabsize) \
             tabsize = self->size; \
         for (i=0; i<tabsize; i++) { \
-            self->data[i] *= PyFloat_AS_DOUBLE(PyNumber_Float(PyList_GET_ITEM(arg, i))); \
+            self->data[i] *= PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
         } \
     } \
  \
@@ -851,7 +858,7 @@ extern PyTypeObject RawMidiType;
         return PyInt_FromLong(-1); \
     } \
     for(i=0; i<self->size; i++) { \
-        self->data[i] = PyFloat_AS_DOUBLE(PyNumber_Float(PyList_GET_ITEM(arg, i))); \
+        self->data[i] = PyFloat_AsDouble(PyList_GET_ITEM(arg, i)); \
     } \
     self->data[self->size] = self->data[0]; \
     Py_RETURN_NONE; \
@@ -1403,7 +1410,7 @@ extern PyTypeObject RawMidiType;
     tmp = arg; \
     Py_INCREF(tmp); \
     if (isNumber == 1) { \
-        if (PyFloat_AsDouble(PyNumber_Float(tmp)) != 0.) { \
+        if (PyFloat_AsDouble(tmp) != 0.) { \
             Py_DECREF(self->mul); \
             self->mul = PyNumber_Divide(PyFloat_FromDouble(1.), PyNumber_Float(tmp)); \
             self->modebuffer[0] = 0; \
@@ -1491,11 +1498,17 @@ extern PyTypeObject RawMidiType;
         Stream_setStreamActive(self->stream, 1); \
     } \
     else { \
-        Stream_setStreamActive(self->stream, 0); \
-        for (i=0; i<self->bufsize; i++) \
-            self->data[i] = 0.0; \
         nearestBuf = (int)roundf((del * self->sr) / self->bufsize); \
-        Stream_setBufferCountWait(self->stream, nearestBuf); \
+        if (nearestBuf <= 0) { \
+            Stream_setBufferCountWait(self->stream, 0); \
+            Stream_setStreamActive(self->stream, 1); \
+        } \
+        else { \
+            Stream_setStreamActive(self->stream, 0); \
+            for (i=0; i<self->bufsize; i++) \
+                self->data[i] = 0.0; \
+            Stream_setBufferCountWait(self->stream, nearestBuf); \
+        } \
     } \
     if (dur == 0) \
         Stream_setDuration(self->stream, 0); \
