@@ -43,6 +43,7 @@ from pyolib.pattern import *
 import pyolib.randoms as randoms
 from pyolib.randoms import *
 from pyolib.server import *
+from pyolib.listener import *
 import pyolib.players as players
 from pyolib.players import *
 import pyolib.tableprocess as tableprocess
@@ -55,11 +56,15 @@ import pyolib.triggers as triggers
 from pyolib.triggers import *
 import pyolib.utils as utils
 from pyolib.utils import *
+import pyolib.expression as expression
+from pyolib.expression import *
 import pyolib.fourier as fourier
 from pyolib.fourier import *
 import pyolib.phasevoc as phasevoc
 from pyolib.phasevoc import *
 from pyolib._core import *
+from pyolib.wxgui import *
+import pyolib.wxgui as wxgui
 if WITH_EXTERNALS:
     import pyolib.external as external
     from pyolib.external import *
@@ -113,11 +118,16 @@ OBJECTS_TREE = {'functions': sorted(['pa_count_devices', 'pa_get_default_input',
                                                     'TrigVal', 'Euclide', 'TrigBurst']),
                                   'utils': sorted(['Clean_objects', 'Print', 'Snap', 'Interp', 'SampHold', 'Compare', 'Record', 'Between', 'Denorm',
                                                     'ControlRec', 'ControlRead', 'NoteinRec', 'NoteinRead', 'DBToA', 'AToDB', 'Scale', 'CentsToTranspo',
-                                                    'TranspoToCents', 'MToF', 'FToM', 'MToT', 'TrackHold']),
+                                                    'TranspoToCents', 'MToF', 'FToM', 'MToT', 'TrackHold', 'Resample', 'Expr']),
+                                  'expression': sorted(['Expr']),
                                   'fourier': sorted(['FFT', 'IFFT', 'CarToPol', 'PolToCar', 'FrameDelta', 'FrameAccum', 'Vectral', 'CvlVerb'])}},
-        'Map': {'SLMap': sorted(['SLMapFreq', 'SLMapMul', 'SLMapPhase', 'SLMapQ', 'SLMapDur', 'SLMapPan'])},
-        'Server': [],
-        'Stream': [],
-        'TableStream': []}
+                'Map': {'SLMap': sorted(['SLMapFreq', 'SLMapMul', 'SLMapPhase', 'SLMapQ', 'SLMapDur', 'SLMapPan'])},
+                'Server': [],
+                'MidiListener': [],
+                'OscListener': [],
+                'Stream': [],
+                'TableStream': [],
+                'PyoGui': ['PyoGuiControlSlider', 'PyoGuiVuMeter', 'PyoGuiGrapher', 'PyoGuiMultiSlider', 'PyoGuiSpectrum', 'PyoGuiScope',
+                           'PyoGuiSndView']}
 
 DOC_KEYWORDS = ['Attributes', 'Examples', 'Parameters', 'Methods', 'Notes', 'Methods details', 'See also', 'Parentclass']
\ No newline at end of file
