@@ -67,47 +67,47 @@ LFO_generates_ii(LFO *self) {
             numh = sharp * 46.0 + 4.0;
             if (numh > maxHarms)
                 numh = maxHarms;
-                for (i=0; i<self->bufsize; i++) {
-                    pointer = self->pointerPos * 2.0 - 1.0;
-                    val = pointer - MYTANH(numh * pointer) / MYTANH(numh);
-                    self->data[i] = val;
-                    self->pointerPos += inc;
-                    if (self->pointerPos < 0)
-                        self->pointerPos += 1.0;
-                    else if (self->pointerPos >= 1)
-                        self->pointerPos -= 1.0;
-                }
+            for (i=0; i<self->bufsize; i++) {
+                pointer = self->pointerPos * 2.0 - 1.0;
+                val = pointer - MYTANH(numh * pointer) / MYTANH(numh);
+                self->data[i] = val;
+                self->pointerPos += inc;
+                if (self->pointerPos < 0)
+                    self->pointerPos += 1.0;
+                else if (self->pointerPos >= 1)
+                    self->pointerPos -= 1.0;
+            }
             break;
         case 1: /* Saw down */
             maxHarms = (int)(self->srOverFour/freq);
             numh = sharp * 46.0 + 4.0;
             if (numh > maxHarms)
                 numh = maxHarms;
-                for (i=0; i<self->bufsize; i++) {
-                    pointer = self->pointerPos * 2.0 - 1.0;
-                    val = -(pointer - MYTANH(numh * pointer) / MYTANH(numh));
-                    self->data[i] = val;
-                    self->pointerPos += inc;
-                    if (self->pointerPos < 0)
-                        self->pointerPos += 1.0;
-                    else if (self->pointerPos >= 1)
-                        self->pointerPos -= 1.0;
-                }
+            for (i=0; i<self->bufsize; i++) {
+                pointer = self->pointerPos * 2.0 - 1.0;
+                val = -(pointer - MYTANH(numh * pointer) / MYTANH(numh));
+                self->data[i] = val;
+                self->pointerPos += inc;
+                if (self->pointerPos < 0)
+                    self->pointerPos += 1.0;
+                else if (self->pointerPos >= 1)
+                    self->pointerPos -= 1.0;
+            }
             break;
         case 2: /* Square */
             maxHarms = (int)(self->srOverEight/freq);
             numh = sharp * 46.0 + 4.0;
             if (numh > maxHarms)
                 numh = maxHarms;
-                for (i=0; i<self->bufsize; i++) {
-                    val = MYATAN(numh * MYSIN(TWOPI*self->pointerPos));
-                    self->data[i] = val * self->oneOverPiOverTwo;
-                    self->pointerPos += inc;
-                    if (self->pointerPos < 0)
-                        self->pointerPos += 1.0;
-                    else if (self->pointerPos >= 1)
-                        self->pointerPos -= 1.0;
-                }
+            for (i=0; i<self->bufsize; i++) {
+                val = MYATAN(numh * MYSIN(TWOPI*self->pointerPos));
+                self->data[i] = val * self->oneOverPiOverTwo;
+                self->pointerPos += inc;
+                if (self->pointerPos < 0)
+                    self->pointerPos += 1.0;
+                else if (self->pointerPos >= 1)
+                    self->pointerPos -= 1.0;
+            }
             break;
         case 3: /* Triangle */
             maxHarms = (int)(self->srOverFour/freq);
@@ -116,7 +116,7 @@ LFO_generates_ii(LFO *self) {
             else
                 numh = sharp;
             for (i=0; i<self->bufsize; i++) {
-                v1 = MYTAN(MYSIN(TWOPI*self->pointerPos));
+                v1 = MYTAN(MYSIN(TWOPI*self->pointerPos)) * self->oneOverPiOverTwo;
                 pointer = self->pointerPos + 0.25;
                 if (pointer > 1.0)
                     pointer -= 1.0;
@@ -175,7 +175,7 @@ LFO_generates_ii(LFO *self) {
                     self->pointerPos -= 1.0;
                     self->sahPointerPos = 0.0;
                     self->sahLastValue = self->sahCurrentValue;
-                    self->sahCurrentValue = rand()/((MYFLT)(RAND_MAX)*0.5) - 1.0;
+                    self->sahCurrentValue = RANDOM_UNIFORM * 2.0 - 1.0;
                 }
                 if (self->sahPointerPos < 1.0) {
                     fade = 0.5 * MYSIN(PI * (self->sahPointerPos+0.5)) + 0.5;
@@ -354,7 +354,7 @@ LFO_generates_ai(LFO *self) {
                     self->pointerPos -= 1.0;
                     self->sahPointerPos = 0.0;
                     self->sahLastValue = self->sahCurrentValue;
-                    self->sahCurrentValue = rand()/((MYFLT)(RAND_MAX)*0.5) - 1.0;
+                    self->sahCurrentValue = RANDOM_UNIFORM * 2.0 - 1.0;
                 }
                 if (self->sahPointerPos < 1.0) {
                     fade = 0.5 * MYSIN(PI * (self->sahPointerPos+0.5)) + 0.5;
@@ -553,7 +553,7 @@ LFO_generates_ia(LFO *self) {
                     self->pointerPos -= 1.0;
                     self->sahPointerPos = 0.0;
                     self->sahLastValue = self->sahCurrentValue;
-                    self->sahCurrentValue = rand()/((MYFLT)(RAND_MAX)*0.5) - 1.0;
+                    self->sahCurrentValue = RANDOM_UNIFORM * 2.0 - 1.0;
                 }
                 if (self->sahPointerPos < 1.0) {
                     fade = 0.5 * MYSIN(PI * (self->sahPointerPos+0.5)) + 0.5;
@@ -768,7 +768,7 @@ LFO_generates_aa(LFO *self) {
                     self->pointerPos -= 1.0;
                     self->sahPointerPos = 0.0;
                     self->sahLastValue = self->sahCurrentValue;
-                    self->sahCurrentValue = rand()/((MYFLT)(RAND_MAX)*0.5) - 1.0;
+                    self->sahCurrentValue = RANDOM_UNIFORM * 2.0 - 1.0;
                 }
                 if (self->sahPointerPos < 1.0) {
                     fade = 0.5 * MYSIN(PI * (self->sahPointerPos+0.5)) + 0.5;
@@ -961,7 +961,7 @@ LFO_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     Server_generateSeed((Server *)self->server, LFO_ID);
 
-    self->sahCurrentValue = self->sahLastValue = rand()/((MYFLT)(RAND_MAX)*0.5) - 1.0;
+    self->sahCurrentValue = self->sahLastValue = RANDOM_UNIFORM * 2.0 - 1.0;
 
     (*self->mode_func_ptr)(self);
 
@@ -993,10 +993,7 @@ LFO_setFreq(LFO *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -1027,10 +1024,7 @@ LFO_setSharp(LFO *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -1061,10 +1055,7 @@ LFO_setType(LFO *self, PyObject *arg)
 {
     int tmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isInt = PyInt_Check(arg);
 
