@@ -105,7 +105,7 @@ WGVerb_process_ii(WGVerb *self) {
             else if (self->rnd_time[j] >= 1.0) {
                 self->rnd_time[j] -= 1.0;
                 self->rnd_oldValue[j] = self->rnd_value[j];
-                self->rnd_value[j] = self->rnd_range[j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[j];
+                self->rnd_value[j] = self->rnd_range[j] * RANDOM_UNIFORM - self->rnd_halfRange[j];
                 self->rnd_diff[j] = self->rnd_value[j] - self->rnd_oldValue[j];
             }
             self->rnd[j] = self->rnd_oldValue[j] + self->rnd_diff[j] * self->rnd_time[j];
@@ -165,7 +165,7 @@ WGVerb_process_ai(WGVerb *self) {
             else if (self->rnd_time[j] >= 1.0) {
                 self->rnd_time[j] -= 1.0;
                 self->rnd_oldValue[j] = self->rnd_value[j];
-                self->rnd_value[j] = self->rnd_range[j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[j];
+                self->rnd_value[j] = self->rnd_range[j] * RANDOM_UNIFORM - self->rnd_halfRange[j];
                 self->rnd_diff[j] = self->rnd_value[j] - self->rnd_oldValue[j];
             }
             self->rnd[j] = self->rnd_oldValue[j] + self->rnd_diff[j] * self->rnd_time[j];
@@ -225,7 +225,7 @@ WGVerb_process_ia(WGVerb *self) {
             else if (self->rnd_time[j] >= 1.0) {
                 self->rnd_time[j] -= 1.0;
                 self->rnd_oldValue[j] = self->rnd_value[j];
-                self->rnd_value[j] = self->rnd_range[j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[j];
+                self->rnd_value[j] = self->rnd_range[j] * RANDOM_UNIFORM - self->rnd_halfRange[j];
                 self->rnd_diff[j] = self->rnd_value[j] - self->rnd_oldValue[j];
             }
             self->rnd[j] = self->rnd_oldValue[j] + self->rnd_diff[j] * self->rnd_time[j];
@@ -285,7 +285,7 @@ WGVerb_process_aa(WGVerb *self) {
             else if (self->rnd_time[j] >= 1.0) {
                 self->rnd_time[j] -= 1.0;
                 self->rnd_oldValue[j] = self->rnd_value[j];
-                self->rnd_value[j] = self->rnd_range[j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[j];
+                self->rnd_value[j] = self->rnd_range[j] * RANDOM_UNIFORM - self->rnd_halfRange[j];
                 self->rnd_diff[j] = self->rnd_value[j] - self->rnd_oldValue[j];
             }
             self->rnd[j] = self->rnd_oldValue[j] + self->rnd_diff[j] * self->rnd_time[j];
@@ -577,10 +577,7 @@ WGVerb_setFeedback(WGVerb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -611,10 +608,7 @@ WGVerb_setCutoff(WGVerb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -645,10 +639,7 @@ WGVerb_setMix(WGVerb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -925,7 +916,7 @@ STReverb_process_ii(STReverb *self) {
                 else if (self->rnd_time[k][j] >= 1.0) {
                     self->rnd_time[k][j] -= 1.0;
                     self->rnd_oldValue[k][j] = self->rnd_value[k][j];
-                    self->rnd_value[k][j] = self->rnd_range[k][j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[k][j];
+                    self->rnd_value[k][j] = self->rnd_range[k][j] * RANDOM_UNIFORM - self->rnd_halfRange[k][j];
                     self->rnd_diff[k][j] = self->rnd_value[k][j] - self->rnd_oldValue[k][j];
                 }
                 self->rnd[k][j] = self->rnd_oldValue[k][j] + self->rnd_diff[k][j] * self->rnd_time[k][j];
@@ -1046,7 +1037,7 @@ STReverb_process_ai(STReverb *self) {
                 else if (self->rnd_time[k][j] >= 1.0) {
                     self->rnd_time[k][j] -= 1.0;
                     self->rnd_oldValue[k][j] = self->rnd_value[k][j];
-                    self->rnd_value[k][j] = self->rnd_range[k][j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[k][j];
+                    self->rnd_value[k][j] = self->rnd_range[k][j] * RANDOM_UNIFORM - self->rnd_halfRange[k][j];
                     self->rnd_diff[k][j] = self->rnd_value[k][j] - self->rnd_oldValue[k][j];
                 }
                 self->rnd[k][j] = self->rnd_oldValue[k][j] + self->rnd_diff[k][j] * self->rnd_time[k][j];
@@ -1168,7 +1159,7 @@ STReverb_process_ia(STReverb *self) {
                 else if (self->rnd_time[k][j] >= 1.0) {
                     self->rnd_time[k][j] -= 1.0;
                     self->rnd_oldValue[k][j] = self->rnd_value[k][j];
-                    self->rnd_value[k][j] = self->rnd_range[k][j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[k][j];
+                    self->rnd_value[k][j] = self->rnd_range[k][j] * RANDOM_UNIFORM - self->rnd_halfRange[k][j];
                     self->rnd_diff[k][j] = self->rnd_value[k][j] - self->rnd_oldValue[k][j];
                 }
                 self->rnd[k][j] = self->rnd_oldValue[k][j] + self->rnd_diff[k][j] * self->rnd_time[k][j];
@@ -1290,7 +1281,7 @@ STReverb_process_aa(STReverb *self) {
                 else if (self->rnd_time[k][j] >= 1.0) {
                     self->rnd_time[k][j] -= 1.0;
                     self->rnd_oldValue[k][j] = self->rnd_value[k][j];
-                    self->rnd_value[k][j] = self->rnd_range[k][j] * (rand()/((MYFLT)(RAND_MAX)+1)) - self->rnd_halfRange[k][j];
+                    self->rnd_value[k][j] = self->rnd_range[k][j] * RANDOM_UNIFORM - self->rnd_halfRange[k][j];
                     self->rnd_diff[k][j] = self->rnd_value[k][j] - self->rnd_oldValue[k][j];
                 }
                 self->rnd[k][j] = self->rnd_oldValue[k][j] + self->rnd_diff[k][j] * self->rnd_time[k][j];
@@ -1579,10 +1570,7 @@ STReverb_setInpos(STReverb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -1613,10 +1601,7 @@ STReverb_setRevtime(STReverb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -1647,10 +1632,7 @@ STReverb_setCutoff(STReverb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -1681,10 +1663,7 @@ STReverb_setMix(STReverb *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -1717,15 +1696,12 @@ STReverb_setRoomSize(STReverb *self, PyObject *arg)
     long maxsize;
 	MYFLT roomSize;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
 	if (isNumber == 1) {
-        roomSize = PyFloat_AS_DOUBLE(PyNumber_Float(arg));
+        roomSize = PyFloat_AsDouble(arg);
         if (roomSize < 0.25)
             roomSize = 0.25;
         else if (roomSize > 4.0)
@@ -1769,15 +1745,12 @@ STReverb_setFirstRefGain(STReverb *self, PyObject *arg)
 {
 	MYFLT tmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
 	if (isNumber == 1) {
-        tmp = PyFloat_AS_DOUBLE(PyNumber_Float(arg));
+        tmp = PyFloat_AsDouble(arg);
         self->firstRefGain = MYPOW(10.0, tmp * 0.05);
 	}
 
